# 23 "asllib/Lexer.mll"
 

exception LexerError

open Parser

open Error

let new_line lexbuf = Lexing.new_line lexbuf; lexbuf
let bitvector_lit lxm = BITVECTOR_LIT (Bitvector.of_string lxm)
let mask_lit lxm = MASK_LIT (Bitvector.mask_of_string lxm)

let tr_name s = match s with
| "AND"           -> AND
| "array"         -> ARRAY
| "as"            -> AS
| "assert"        -> ASSERT
| "begin"         -> BEGIN
| "bit"           -> BIT
| "bits"          -> BITS
| "boolean"       -> BOOLEAN
| "case"          -> CASE
| "catch"         -> CATCH
| "config"        -> CONFIG
| "constant"      -> CONSTANT
| "__debug__"|"__DEBUG__" -> DEBUG
| "DIV"           -> DIV
| "DIVRM"         -> DIVRM
| "do"            -> DO
| "downto"        -> DOWNTO
| "else"          -> ELSE
| "elsif"         -> ELSIF
| "end"           -> END
| "enumeration"   -> ENUMERATION
| "XOR"           -> EOR
| "exception"     -> EXCEPTION
| "FALSE"         -> BOOL_LIT false
| "for"           -> FOR
| "func"          -> FUNC
| "getter"        -> GETTER
| "if"            -> IF
| "IN"            -> IN
| "integer"       -> INTEGER
| "let"           -> LET
(*
| "limit"         -> LIMIT
 *)
| "MOD"           -> MOD
| "NOT"           -> NOT
| "of"            -> OF
| "OR"            -> OR
| "otherwise"     -> OTHERWISE
| "pass"          -> PASS
| "pragma"        -> PRAGMA
| "print"         -> PRINT
| "real"          -> REAL
| "record"        -> RECORD
| "repeat"        -> REPEAT
| "return"        -> RETURN
| "setter"        -> SETTER
| "string"        -> STRING
| "subtypes"      -> SUBTYPES
| "then"          -> THEN
| "throw"         -> THROW
| "to"            -> TO
| "try"           -> TRY
| "TRUE"          -> BOOL_LIT true
| "type"          -> TYPE
| "UNKNOWN"       -> UNKNOWN
| "Unreachable"   -> UNREACHABLE
| "until"         -> UNTIL
| "var"           -> VAR
| "when"          -> WHEN
| "where"         -> WHERE
| "while"         -> WHILE
| "with"          -> WITH
(* Reserved identifiers *)
| "SAMPLE" | "UNSTABLE"
| "_" | "access" | "advice" | "after"
| "any" | "aspect"
| "assume" | "assumes" | "before"
| "call" | "cast"
| "class" | "dict"
| "endcase" | "endcatch" | "endclass"
| "endevent" | "endfor" | "endfunc" | "endgetter"
| "endif" | "endmodule" | "endnamespace" | "endpackage"
| "endproperty" | "endrule" | "endsetter" | "endtemplate"
| "endtry" | "endwhile" | "entry"
| "event" | "export" | "expression"
| "extends" | "extern" | "feature"
| "get" | "gives"
| "iff" | "implies" | "import"
| "intersect" | "intrinsic"
| "invariant" | "is" | "list"
| "map" | "module" | "namespace" | "newevent"
| "newmap" | "original"
| "package" | "parallel" (* | "pattern" *)
| "pointcut" | "port" | "private"
| "profile" | "property" | "protected" | "public"
| "replace"
| "requires" | "rethrow" | "rule"
| "set" | "shared" | "signal"
| "statements" | "template"
| "typeof" | "union"
| "using" | "watch"
| "ztype" -> Error.fatal_unknown_pos @@ (Error.ReservedIdentifier s)
(* End of reserved identifiers *)
| x               -> IDENTIFIER x


# 113 "asllib/Lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base =
   "\000\000\251\255\252\255\253\255\254\255\255\255\001\000\002\000\
    \253\255\254\255\255\255\003\000\004\000\253\255\000\000\255\255\
    \086\000\208\255\196\000\000\000\212\255\218\255\000\000\001\000\
    \025\000\002\000\226\255\229\255\230\255\234\255\000\000\002\000\
    \237\255\238\255\004\000\000\000\002\000\005\000\244\255\006\000\
    \031\001\248\255\022\000\039\001\009\000\007\000\255\255\252\255\
    \031\000\032\000\063\001\118\001\049\001\058\000\247\255\033\001\
    \246\255\233\255\227\255\007\000\239\255\231\255\211\255\242\255\
    \241\255\029\000\240\255\236\255\219\255\223\255\213\255\222\255\
    \214\255\217\255\216\255\000\000\001\000\001\000\001\000\000\000\
    \005\000\010\000\005\000\210\255";
  Lexing.lex_backtrk =
   "\255\255\255\255\255\255\255\255\255\255\255\255\004\000\003\000\
    \255\255\255\255\255\255\004\000\003\000\255\255\001\000\255\255\
    \048\000\255\255\046\000\255\255\255\255\255\255\035\000\034\000\
    \255\255\030\000\255\255\255\255\255\255\255\255\020\000\027\000\
    \255\255\255\255\023\000\255\255\040\000\012\000\255\255\010\000\
    \255\255\255\255\004\000\004\000\031\000\001\000\255\255\255\255\
    \002\000\255\255\255\255\005\000\006\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255";
  Lexing.lex_default =
   "\001\000\000\000\000\000\000\000\000\000\000\000\007\000\007\000\
    \000\000\000\000\000\000\012\000\012\000\000\000\255\255\000\000\
    \255\255\000\000\255\255\255\255\000\000\000\000\255\255\255\255\
    \255\255\255\255\000\000\000\000\000\000\000\000\255\255\255\255\
    \000\000\000\000\255\255\255\255\255\255\255\255\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\000\000\
    \048\000\255\255\255\255\255\255\255\255\255\255\000\000\255\255\
    \000\000\000\000\000\000\255\255\000\000\000\000\000\000\000\000\
    \000\000\255\255\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\000\000";
  Lexing.lex_trans =
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\008\000\255\255\013\000\255\255\000\000\
    \045\000\000\000\000\000\000\000\045\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\003\000\010\000\255\255\000\000\064\000\045\000\
    \000\000\255\255\000\000\000\000\073\000\014\000\255\255\015\000\
    \067\000\065\000\059\000\047\000\000\000\000\000\000\000\000\000\
    \048\000\000\000\074\000\072\000\070\000\069\000\068\000\062\000\
    \063\000\060\000\058\000\057\000\049\000\061\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \052\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\053\000\066\000\002\000\009\000\255\255\045\000\
    \046\000\056\000\000\000\045\000\000\000\000\000\000\000\000\000\
    \000\000\080\000\053\000\053\000\075\000\079\000\005\000\076\000\
    \077\000\078\000\081\000\082\000\004\000\042\000\045\000\039\000\
    \041\000\083\000\000\000\000\000\035\000\040\000\027\000\032\000\
    \025\000\023\000\038\000\034\000\031\000\044\000\043\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \022\000\020\000\037\000\030\000\036\000\071\000\019\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\028\000\053\000\033\000\026\000\018\000\000\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\029\000\024\000\021\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\000\000\000\000\
    \255\255\255\255\255\255\255\255\255\255\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\255\255\
    \000\000\000\000\000\000\018\000\000\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\040\000\
    \000\000\055\000\000\000\000\000\000\000\000\000\054\000\000\000\
    \054\000\000\000\000\000\000\000\000\000\000\000\000\000\040\000\
    \040\000\055\000\055\000\000\000\000\000\049\000\017\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \042\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\000\000\000\000\000\000\000\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\042\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \052\000\000\000\000\000\000\000\000\000\000\000\000\000\053\000\
    \000\000\055\000\000\000\055\000\000\000\000\000\000\000\050\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\051\000\000\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check =
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\006\000\007\000\011\000\012\000\255\255\
    \045\000\255\255\255\255\255\255\045\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\000\000\006\000\007\000\255\255\035\000\045\000\
    \255\255\048\000\255\255\255\255\023\000\011\000\012\000\014\000\
    \031\000\034\000\037\000\044\000\255\255\255\255\255\255\255\255\
    \044\000\255\255\022\000\023\000\025\000\030\000\030\000\036\000\
    \036\000\037\000\037\000\039\000\042\000\059\000\042\000\042\000\
    \042\000\042\000\042\000\042\000\042\000\042\000\042\000\042\000\
    \049\000\049\000\049\000\049\000\049\000\049\000\049\000\049\000\
    \049\000\049\000\053\000\065\000\000\000\006\000\007\000\016\000\
    \016\000\053\000\255\255\016\000\255\255\255\255\255\255\255\255\
    \255\255\079\000\053\000\053\000\019\000\078\000\000\000\075\000\
    \076\000\077\000\080\000\081\000\000\000\042\000\016\000\016\000\
    \016\000\082\000\255\255\255\255\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\024\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\053\000\016\000\016\000\016\000\255\255\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\016\000\016\000\016\000\016\000\
    \016\000\016\000\016\000\016\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\255\255\255\255\
    \000\000\006\000\007\000\011\000\012\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\048\000\
    \255\255\255\255\255\255\018\000\255\255\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\018\000\
    \018\000\018\000\018\000\018\000\018\000\018\000\018\000\040\000\
    \255\255\055\000\255\255\255\255\255\255\255\255\040\000\255\255\
    \055\000\255\255\255\255\255\255\255\255\255\255\255\255\040\000\
    \040\000\055\000\055\000\255\255\255\255\043\000\016\000\043\000\
    \043\000\043\000\043\000\043\000\043\000\043\000\043\000\043\000\
    \043\000\052\000\052\000\052\000\052\000\052\000\052\000\052\000\
    \052\000\052\000\052\000\255\255\255\255\255\255\255\255\050\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\050\000\050\000\
    \050\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \050\000\050\000\050\000\050\000\050\000\050\000\043\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \052\000\255\255\255\255\255\255\255\255\255\255\255\255\040\000\
    \255\255\040\000\255\255\055\000\255\255\255\255\255\255\043\000\
    \050\000\050\000\050\000\050\000\050\000\050\000\051\000\051\000\
    \051\000\051\000\051\000\051\000\051\000\051\000\051\000\051\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\051\000\
    \051\000\051\000\051\000\051\000\051\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\051\000\255\255\051\000\
    \051\000\051\000\051\000\051\000\051\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code =
   "";
  Lexing.lex_backtrk_code =
   "";
  Lexing.lex_default_code =
   "";
  Lexing.lex_trans_code =
   "";
  Lexing.lex_check_code =
   "";
  Lexing.lex_code =
   "";
}

let rec escaped_string_chars acc lexbuf =
   __ocaml_lex_escaped_string_chars_rec acc lexbuf 0
and __ocaml_lex_escaped_string_chars_rec acc lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 166 "asllib/Lexer.mll"
         ( Buffer.add_char acc '\n'; string_lit acc lexbuf )
# 332 "asllib/Lexer.ml"

  | 1 ->
# 167 "asllib/Lexer.mll"
         ( Buffer.add_char acc '\t'; string_lit acc lexbuf )
# 337 "asllib/Lexer.ml"

  | 2 ->
# 168 "asllib/Lexer.mll"
         ( Buffer.add_char acc '"'; string_lit acc lexbuf )
# 342 "asllib/Lexer.ml"

  | 3 ->
# 169 "asllib/Lexer.mll"
         ( Buffer.add_char acc '\\'; string_lit acc lexbuf )
# 347 "asllib/Lexer.ml"

  | 4 ->
# 170 "asllib/Lexer.mll"
                         ( raise LexerError )
# 352 "asllib/Lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_escaped_string_chars_rec acc lexbuf __ocaml_lex_state

and string_lit acc lexbuf =
   __ocaml_lex_string_lit_rec acc lexbuf 6
and __ocaml_lex_string_lit_rec acc lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 173 "asllib/Lexer.mll"
          ( STRING_LIT (Buffer.contents acc) )
# 364 "asllib/Lexer.ml"

  | 1 ->
# 174 "asllib/Lexer.mll"
          ( escaped_string_chars acc lexbuf )
# 369 "asllib/Lexer.ml"

  | 2 ->
# 175 "asllib/Lexer.mll"
          ( Buffer.add_char acc '\n'; new_line lexbuf |> string_lit acc )
# 374 "asllib/Lexer.ml"

  | 3 ->
let
# 176 "asllib/Lexer.mll"
                          lxm
# 380 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 176 "asllib/Lexer.mll"
                              ( Buffer.add_string acc lxm; string_lit acc lexbuf )
# 384 "asllib/Lexer.ml"

  | 4 ->
# 177 "asllib/Lexer.mll"
          ( raise LexerError )
# 389 "asllib/Lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_string_lit_rec acc lexbuf __ocaml_lex_state

and c_comments lexbuf =
   __ocaml_lex_c_comments_rec lexbuf 11
and __ocaml_lex_c_comments_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 185 "asllib/Lexer.mll"
                  ( token      lexbuf )
# 401 "asllib/Lexer.ml"

  | 1 ->
# 186 "asllib/Lexer.mll"
                  ( c_comments lexbuf )
# 406 "asllib/Lexer.ml"

  | 2 ->
# 187 "asllib/Lexer.mll"
                  ( new_line lexbuf |> c_comments )
# 411 "asllib/Lexer.ml"

  | 3 ->
# 188 "asllib/Lexer.mll"
                  ( c_comments lexbuf )
# 416 "asllib/Lexer.ml"

  | 4 ->
# 189 "asllib/Lexer.mll"
                  ( raise LexerError  )
# 421 "asllib/Lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_c_comments_rec lexbuf __ocaml_lex_state

and token lexbuf =
   __ocaml_lex_token_rec lexbuf 16
and __ocaml_lex_token_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 197 "asllib/Lexer.mll"
                               ( new_line lexbuf |> token         )
# 433 "asllib/Lexer.ml"

  | 1 ->
# 198 "asllib/Lexer.mll"
                               ( token lexbuf                     )
# 438 "asllib/Lexer.ml"

  | 2 ->
# 199 "asllib/Lexer.mll"
                               ( token lexbuf                     )
# 443 "asllib/Lexer.ml"

  | 3 ->
# 200 "asllib/Lexer.mll"
                               ( c_comments lexbuf                )
# 448 "asllib/Lexer.ml"

  | 4 ->
let
# 201 "asllib/Lexer.mll"
                 lxm
# 454 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 201 "asllib/Lexer.mll"
                               ( INT_LIT(Z.of_string lxm)         )
# 458 "asllib/Lexer.ml"

  | 5 ->
let
# 202 "asllib/Lexer.mll"
                 lxm
# 464 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 202 "asllib/Lexer.mll"
                               ( INT_LIT(Z.of_string lxm)         )
# 468 "asllib/Lexer.ml"

  | 6 ->
let
# 203 "asllib/Lexer.mll"
                  lxm
# 474 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 203 "asllib/Lexer.mll"
                               ( REAL_LIT(Q.of_string lxm)        )
# 478 "asllib/Lexer.ml"

  | 7 ->
# 204 "asllib/Lexer.mll"
                               ( string_lit (Buffer.create 16) lexbuf )
# 483 "asllib/Lexer.ml"

  | 8 ->
let
# 205 "asllib/Lexer.mll"
                    lxm
# 489 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_start_pos + 1) (lexbuf.Lexing.lex_curr_pos + -1) in
# 205 "asllib/Lexer.mll"
                               ( bitvector_lit lxm                )
# 493 "asllib/Lexer.ml"

  | 9 ->
let
# 206 "asllib/Lexer.mll"
                    lxm
# 499 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf (lexbuf.Lexing.lex_start_pos + 1) (lexbuf.Lexing.lex_curr_pos + -1) in
# 206 "asllib/Lexer.mll"
                               ( mask_lit lxm                     )
# 503 "asllib/Lexer.ml"

  | 10 ->
# 207 "asllib/Lexer.mll"
                               ( BNOT                             )
# 508 "asllib/Lexer.ml"

  | 11 ->
# 208 "asllib/Lexer.mll"
                               ( COMMA                            )
# 513 "asllib/Lexer.ml"

  | 12 ->
# 209 "asllib/Lexer.mll"
                               ( LT                               )
# 518 "asllib/Lexer.ml"

  | 13 ->
# 210 "asllib/Lexer.mll"
                               ( SHR                              )
# 523 "asllib/Lexer.ml"

  | 14 ->
# 211 "asllib/Lexer.mll"
                               ( BAND                             )
# 528 "asllib/Lexer.ml"

  | 15 ->
# 212 "asllib/Lexer.mll"
                               ( IMPL                             )
# 533 "asllib/Lexer.ml"

  | 16 ->
# 213 "asllib/Lexer.mll"
                               ( SHL                              )
# 538 "asllib/Lexer.ml"

  | 17 ->
# 214 "asllib/Lexer.mll"
                               ( RBRACKET                         )
# 543 "asllib/Lexer.ml"

  | 18 ->
# 215 "asllib/Lexer.mll"
                               ( RPAR                             )
# 548 "asllib/Lexer.ml"

  | 19 ->
# 216 "asllib/Lexer.mll"
                               ( SLICING                          )
# 553 "asllib/Lexer.ml"

  | 20 ->
# 217 "asllib/Lexer.mll"
                               ( EQ                               )
# 558 "asllib/Lexer.ml"

  | 21 ->
# 218 "asllib/Lexer.mll"
                               ( LBRACE                           )
# 563 "asllib/Lexer.ml"

  | 22 ->
# 219 "asllib/Lexer.mll"
                               ( NEQ                              )
# 568 "asllib/Lexer.ml"

  | 23 ->
# 220 "asllib/Lexer.mll"
                               ( MINUS                            )
# 573 "asllib/Lexer.ml"

  | 24 ->
# 221 "asllib/Lexer.mll"
                               ( BEQ                              )
# 578 "asllib/Lexer.ml"

  | 25 ->
# 222 "asllib/Lexer.mll"
                               ( LBRACKET                         )
# 583 "asllib/Lexer.ml"

  | 26 ->
# 223 "asllib/Lexer.mll"
                               ( LPAR                             )
# 588 "asllib/Lexer.ml"

  | 27 ->
# 224 "asllib/Lexer.mll"
                               ( DOT                              )
# 593 "asllib/Lexer.ml"

  | 28 ->
# 225 "asllib/Lexer.mll"
                               ( LEQ                              )
# 598 "asllib/Lexer.ml"

  | 29 ->
# 226 "asllib/Lexer.mll"
                               ( POW                              )
# 603 "asllib/Lexer.ml"

  | 30 ->
# 227 "asllib/Lexer.mll"
                               ( MUL                              )
# 608 "asllib/Lexer.ml"

  | 31 ->
# 228 "asllib/Lexer.mll"
                               ( RDIV                             )
# 613 "asllib/Lexer.ml"

  | 32 ->
# 229 "asllib/Lexer.mll"
                               ( EQ_OP                            )
# 618 "asllib/Lexer.ml"

  | 33 ->
# 230 "asllib/Lexer.mll"
                               ( BOR                              )
# 623 "asllib/Lexer.ml"

  | 34 ->
# 231 "asllib/Lexer.mll"
                               ( PLUS                             )
# 628 "asllib/Lexer.ml"

  | 35 ->
# 232 "asllib/Lexer.mll"
                               ( COLON                            )
# 633 "asllib/Lexer.ml"

  | 36 ->
# 233 "asllib/Lexer.mll"
                               ( ARROW                            )
# 638 "asllib/Lexer.ml"

  | 37 ->
# 234 "asllib/Lexer.mll"
                               ( RBRACE                           )
# 643 "asllib/Lexer.ml"

  | 38 ->
# 235 "asllib/Lexer.mll"
                               ( CONCAT                           )
# 648 "asllib/Lexer.ml"

  | 39 ->
# 236 "asllib/Lexer.mll"
                               ( COLON_COLON                      )
# 653 "asllib/Lexer.ml"

  | 40 ->
# 237 "asllib/Lexer.mll"
                               ( GT                               )
# 658 "asllib/Lexer.ml"

  | 41 ->
# 238 "asllib/Lexer.mll"
                               ( PLUS_COLON                       )
# 663 "asllib/Lexer.ml"

  | 42 ->
# 239 "asllib/Lexer.mll"
                               ( STAR_COLON                       )
# 668 "asllib/Lexer.ml"

  | 43 ->
# 240 "asllib/Lexer.mll"
                               ( SEMI_COLON                       )
# 673 "asllib/Lexer.ml"

  | 44 ->
# 241 "asllib/Lexer.mll"
                               ( GEQ                              )
# 678 "asllib/Lexer.ml"

  | 45 ->
# 242 "asllib/Lexer.mll"
                               ( ARROBASE_LOOPLIMIT               )
# 683 "asllib/Lexer.ml"

  | 46 ->
let
# 243 "asllib/Lexer.mll"
                    lxm
# 689 "asllib/Lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 243 "asllib/Lexer.mll"
                               ( tr_name lxm                      )
# 693 "asllib/Lexer.ml"

  | 47 ->
# 244 "asllib/Lexer.mll"
                               ( EOF                              )
# 698 "asllib/Lexer.ml"

  | 48 ->
# 245 "asllib/Lexer.mll"
                               ( raise LexerError                 )
# 703 "asllib/Lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf;
      __ocaml_lex_token_rec lexbuf __ocaml_lex_state

;;

